#############################
####Scavenging Analysis
#############################

#Loading required packages
library(tidyr)
library(dplyr)
library(MuMIn)
library(BiodiversityR)
library(ggplot2)
library(grid)
library(gridExtra)
library(cowplot)

###ANALYSES
#Loading data for each analysis
scav <- read.csv("scav_data.csv")

scav$Forest<-as.factor(scav$Forest)

time_first <- scav %>% 
  filter(Time.Until.First.Scavenger=="Y")

time_rem <- scav %>% 
  filter(Time.Until.Removal=="Y")

#time until removal model selection
options(na.action = "na.fail")
rem <-glm(time_to_removal ~ Carcass_Type + Forest + Season + temp, data=time_rem, family=Gamma(link="log"))

drem <- dredge(rem, beta = "none", m.lim = c(0, 4), subset = !(Season && temp))
subset(drem)

rem_mod <- glm(time_to_removal ~ Carcass_Type + temp, data=time_rem, family=Gamma(link="log"))
summary(rem_mod)
deviancepercentage(rem_mod,time_rem,test="F",digits=2)

##time until first model selection
options(na.action = "na.fail")
first <-glm(time_to_first ~ Carcass_Type + Forest + Season + temp, data=time_first, family=Gamma(link="log"))

dfirst <- dredge(first, beta = "none", m.lim = c(0, 4), subset = !(Season && temp))
subset(dfirst)

first_mod <- glm(time_to_first ~ Carcass_Type + Season, data=time_first, family=Gamma(link="log"))
summary(first_mod)
deviancepercentage(first_mod,time_first,test="F",digits=2)

###FIGURES
#ggplot color/fillscales
scale_fill_Publication <- function(...){
  library(scales)
  discrete_scale("fill","Publication",manual_pal(values = c("#386cb0","#fdb462","#7fc97f","#ef3b2c","#662506","#a6cee3","#fb9a99","#984ea3","#ffff33")), ...)
}
scale_colour_Publication <- function(...){
  library(scales)
  discrete_scale("colour","Publication",manual_pal(values = c("#386cb0","#fdb462","#7fc97f","#ef3b2c","#662506","#a6cee3","#fb9a99","#984ea3","#ffff33")), ...)
}

#custom ggplot theme
theme_Publication <- function(...){
  theme_bw()+
    theme(plot.title = element_text(face = "bold",
                                    size = rel(1.2), hjust = 0.5),
          text = element_text(),
          panel.background = element_rect(colour = NA),
          plot.background = element_rect(colour = NA),
          panel.border = element_rect(colour = NA),
          axis.title = element_text(face = "bold",size = rel(1.3)),
          axis.title.y = element_text(angle=90,vjust =2),
          axis.title.x = element_text(vjust = -0.2),
          axis.text = element_text(size = rel(1.1)), 
          axis.line = element_line(colour="black"),
          axis.ticks = element_line(),
          panel.grid.major = element_line(colour="#f0f0f0"),
          panel.grid.minor = element_blank(),
          legend.key = element_rect(colour = NA),
          legend.position = "bottom",
          legend.direction = "horizontal",
          legend.key.size= unit(0.6, "cm"),
          legend.spacing = unit(0.1, "cm"),
          legend.text = element_text(size = rel(1)),
          legend.title = element_blank(),
          plot.margin=unit(c(10,5,5,5),"mm"),
          strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
          strip.text = element_text(face="bold"))
}

#Plotting scavenging efficiency
a <- ggplot(data = time_first, aes(x = factor(Carcass_Type), y = time_to_first, fill=factor(Carcass_Type))) +
  geom_boxplot(outlier.shape=NA, alpha=0.7)+geom_jitter(width=0.1, alpha=0.5) +
  scale_fill_Publication()+
  scale_colour_Publication()+
  theme_Publication()+
  ylab("First scavenger (d)") +
  xlab("Carcass type")+
  ylim(0,15) +
  labs(tag="a")+
  scale_x_discrete(labels=c("Carnivore", "Herbivore"))+
  theme(legend.position = "none", plot.tag.position = c(0.25, 0.9), 
        plot.tag = element_text(size=14))
a

b <- ggplot(data = time_rem, aes(x = factor(Carcass_Type), y = time_to_removal, fill=factor(Carcass_Type))) +
  geom_boxplot(outlier.shape=NA, alpha=0.7)+geom_jitter(width=0.1, alpha=0.5) +
  scale_fill_Publication()+
  scale_colour_Publication()+
  theme_Publication()+
  ylab("Carcass persistence (d)") +
  xlab("Carcass type")+
  ylim(0,175) +
  labs(tag="b")+
  scale_x_discrete(labels=c("Carnivore", "Herbivore"))+
  theme(legend.position = "none", plot.tag.position = c(0.3, 0.9), 
        plot.tag = element_text(size=14))
b

x.grob <- textGrob("Carcass type", 
                   gp=gpar(fontsize=15))
bb<-grid.arrange(arrangeGrob(a,b, ncol=2))
plot_grid(bb)
ggsave("Fig1.jpeg", width=6, height=3, units="in", dpi=300)
